======
pkgdev
======

.. include:: pkgdev/_synopsis.rst
.. include:: pkgdev/_description.rst
.. include:: pkgdev/_options.rst
.. include:: pkgdev/_subcommands.rst

.. include:: config.rst

Reporting Bugs
==============

Please submit an issue via github:

https://github.com/pkgcore/pkgdev/issues
